@@ -1,21 +1,21 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 ### BEGIN LICENSE
 # Copyright (c) 2012, Peter Levi <peterlevi@peterlevi.com>
-# This program is free software: you can redistribute it and/or modify it 
-# under the terms of the GNU General Public License version 3, as published 
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License version 3, as published
 # by the Free Software Foundation.
-# 
-# This program is distributed in the hope that it will be useful, but 
-# WITHOUT ANY WARRANTY; without even the implied warranties of 
-# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 # PURPOSE.  See the GNU General Public License for more details.
-# 
-# You should have received a copy of the GNU General Public License along 
+#
+# You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 ### END LICENSE
 
-from collections import defaultdict
 import json
+from collections import defaultdict
 
 
 class AttrDict(defaultdict):
@@ -32,7 +32,7 @@ class AttrDict(defaultdict):
             return v
 
     def merge(self, arg):
-        if hasattr(arg, 'items'):
+        if hasattr(arg, "items"):
             self.merge(arg.items())
         else:
             for k, v in arg:
@@ -46,7 +46,9 @@ class AttrDict(defaultdict):
         if len(args) == 1:
             self.merge(args[0])
         elif len(args) > 1:
-            raise TypeError("AttrDict expected at most 1 argument that is a map, got %i" % len(args))
+            raise TypeError(
+                "AttrDict expected at most 1 argument that is a map, got %i" % len(args)
+            )
         self.merge(kwargs)
 
     def __setitem__(self, k, v):
@@ -54,5 +56,3 @@ class AttrDict(defaultdict):
 
     __getattr__ = defaultdict.__getitem__
     __setattr__ = __setitem__
-
-
